==> omemo-dr-0.99.0.tar.gz: omemo-dr-0.99.0/src/omemo_dr/state/signedprekeyrecord.py <==
from __future__ import annotations

from typing import cast

import google.protobuf.message

from ..ecc.curve import Curve
from ..ecc.eckeypair import ECKeyPair
from .storageprotos_pb2 import SignedPreKeyRecordStructure


class SignedPreKeyRecord:
    def __init__(self, structure: SignedPreKeyRecordStructureProto) -> None:
        self._structure = structure

    @classmethod
    def new(
        cls, _id: int, timestamp: int, ecKeyPair: ECKeyPair, signature: bytes
    ) -> SignedPreKeyRecord:
        record = cast(SignedPreKeyRecordStructureProto, SignedPreKeyRecordStructure())

        record.id = _id
        record.publicKey = ecKeyPair.getPublicKey().serialize()
        record.privateKey = ecKeyPair.getPrivateKey().serialize()
        record.signature = signature
        record.timestamp = timestamp

        return cls(record)

    @classmethod
    def from_bytes(cls, serialized: bytes) -> SignedPreKeyRecord:
        record = cast(SignedPreKeyRecordStructureProto, SignedPreKeyRecordStructure())
        record.ParseFromString(serialized)
        return cls(record)

    def getId(self) -> int:
        return self._structure.id

    def getTimestamp(self) -> int:
        return self._structure.timestamp

    def getKeyPair(self) -> ECKeyPair:
        publicKey = Curve.decodePoint(bytearray(self._structure.publicKey), 0)
        privateKey = Curve.decodePrivatePoint(bytearray(self._structure.privateKey))

        return ECKeyPair(publicKey, privateKey)

    def getSignature(self) -> bytes:
        return self._structure.signature

    def serialize(self) -> bytes:
        return self._structure.SerializeToString()


class SignedPreKeyRecordStructureProto(google.protobuf.message.Message):
    id: int
    publicKey: bytes
    privateKey: bytes
    signature: bytes
    timestamp: int

==> omemo-dr-0.99.1.tar.gz: omemo-dr-0.99.1/src/omemo_dr/state/signedprekeyrecord.py <==
from __future__ import annotations

from typing import cast

import google.protobuf.message

from ..ecc.curve import Curve
from ..ecc.eckeypair import ECKeyPair
from .storageprotos_pb2 import SignedPreKeyRecordStructure


class SignedPreKeyRecord:
    def __init__(self, structure: SignedPreKeyRecordStructureProto) -> None:
        self._structure = structure

    @classmethod
    def new(
        cls, _id: int, timestamp: int, ec_key_pair: ECKeyPair, signature: bytes
    ) -> SignedPreKeyRecord:
        record = cast(SignedPreKeyRecordStructureProto, SignedPreKeyRecordStructure())

        record.id = _id
        record.publicKey = ec_key_pair.get_public_key().serialize()
        record.privateKey = ec_key_pair.get_private_key().serialize()
        record.signature = signature
        record.timestamp = timestamp

        return cls(record)

    @classmethod
    def from_bytes(cls, serialized: bytes) -> SignedPreKeyRecord:
        record = cast(SignedPreKeyRecordStructureProto, SignedPreKeyRecordStructure())
        record.ParseFromString(serialized)
        return cls(record)

    def get_id(self) -> int:
        return self._structure.id

    def get_timestamp(self) -> int:
        return self._structure.timestamp

    def get_key_pair(self) -> ECKeyPair:
        public_key = Curve.decode_point(bytearray(self._structure.publicKey), 0)
        private_key = Curve.decode_private_point(bytearray(self._structure.privateKey))

        return ECKeyPair(public_key, private_key)

    def get_signature(self) -> bytes:
        return self._structure.signature

    def serialize(self) -> bytes:
        return self._structure.SerializeToString()


class SignedPreKeyRecordStructureProto(google.protobuf.message.Message):
    id: int
    publicKey: bytes
    privateKey: bytes
    signature: bytes
    timestamp: int
